Changelog
=========

0.9.2 (2015-10-28)
------------------

* Moved source repository from Bitbucket to Github
* Added experimental warning to the README
* Added an example to the README

0.9.1 (2015-10-27)
------------------

* Added README, CHANGELOG, AUTHORS
* New maintainer: Alex Willmer
* Changed from distutils to setuptools

0.9 (2015-10-27)
----------------

* First release on PyPI
